#ifndef NT2_INCLUDE_FUNCTIONS_ACOTH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACOTH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/acoth.hpp>

#endif
